require 'gem2deb/rake/spectask'

Gem2Deb::Rake::RSpecTask.new do |spec|
  spec.pattern = './spec/**/*_spec.rb'
  spec.exclude_pattern = './spec/foreman/export/**/*_spec.rb' if ENV['AUTOPKGTEST_TMP']
  spec.rspec_opts = '--format doc --backtrace --seed 47932'
end
